package com.ibm.commerce.usermanagement.custom.commands;

/*
 *-------------------------------------------------------------------
 * Licensed Materials - Property of IBM
 *
 * 5724-A18
 *
 * (c) Copyright International Business Machines Corporation. 2003,2004
 *     All rights reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 *-------------------------------------------------------------------
 */

//*---------------------------------------------------------------------
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been
//* thoroughly tested under all conditions.  IBM, therefore, cannot
//* guarantee its reliability, serviceability or functionality.
//*
//* This sample may include the names of individuals, companies, brands
//* and products in order to illustrate concepts as completely as
//* possible.  All of these names are fictitious and any similarity
//* to the names and addresses used by actual persons or business
//* enterprises is entirely coincidental.
//*---------------------------------------------------------------------
//*

import java.util.Enumeration;
import com.ibm.commerce.datatype.TypedProperty;

import com.ibm.commerce.ras.ECTrace;
import com.ibm.commerce.ras.ECTraceIdentifiers;
import com.ibm.commerce.ras.ECMessage;
import com.ibm.commerce.ras.ECMessageHelper;
import com.ibm.commerce.exception.ECException;
import com.ibm.commerce.exception.ECSystemException;

import com.ibm.commerce.messaging.outboundservice.Messaging;
import com.ibm.commerce.messaging.objects.MsgTypesAccessBean;

import com.ibm.commerce.usermanagement.commands.PostOrgEntityAddCmd;
import com.ibm.commerce.usermanagement.commands.PostOrgEntityAddCmdImpl;
import com.ibm.commerce.usermanagement.commands.ECUserConstants;

/**
 * This implementation overrides the default implementation class for PostOrgEntityAdd command.
 * It composes an XML message and sends the message using the MQ transport.
 */
public class ExtendedPostOrgEntityAddCmdImpl extends PostOrgEntityAddCmdImpl implements PostOrgEntityAddCmd
{
    /**
     * IBM Copyright notice field.
     */
    public static final String COPYRIGHT = com.ibm.commerce.copyright.IBMCopyright.SHORT_COPYRIGHT;
    /**
     * The name of this implementation of the command.
     */
    public final static String CLASSNAME = "SiebelPostOrgEntityAddCmdImpl";
    /**
     * The request properties.
     */
    protected TypedProperty requestProperties = null;
    /**
     * The response properties.
     */
    protected TypedProperty responseProperties = null;

/**
 * Returns the request properties.
 * @return The request properties.
 */
    public TypedProperty getRequestProperties()
    {
        return requestProperties;
    }
/**
 * Returns the response properties.
 * @return The response properties.
 */
    public TypedProperty getResponseProperties()
    {
        return responseProperties;
    }
/**
 * Performs the business logic.
 * It creates an XML message to represent the information of the newly registered
 * Organization, and sends the message to the backend system.
 * @exception com.ibm.commerce.exception.ECException
 */
    public void performExecute() throws ECException
    {
        super.performExecute();
        final String METHODNAME = "performExecute";
        ECTrace.entry(ECTraceIdentifiers.COMPONENT_EXTERN, CLASSNAME, METHODNAME);


		// get deviceFormat from Command Context

		Integer deviceFormat = getCommandContext().getDeviceFormatId();
		ECTrace.trace(ECTraceIdentifiers.COMPONENT_EXTERN,CLASSNAME, METHODNAME,"Device Format value =  "+  deviceFormat.intValue() + " \r\n");

		// if the request is from browser i.e. OrgAdminconsole, deviceformat would be -1
		// if the request is from MQ then deviceformat will be -20000
		// do not execute this piece of code when the device format = -20000

		if (deviceFormat.intValue() != -20000)
		{

       		// it gathers the information, compose XML message, sends to the conifgured message transport.
        	createOrgentityMessage();
		}

        ECTrace.exit(ECTraceIdentifiers.COMPONENT_EXTERN,CLASSNAME,METHODNAME);
    }
/**
 * Sets the request properties.
 * @param aRequestProperties the request properties.
 */
    public void setRequestProperties(TypedProperty aRequestProperties)
    {
        requestProperties = aRequestProperties;
    }
/**
 * Sets the response properties.
 * @param aResponseProperties the response properties.
 */
    public void setResponseProperties(TypedProperty aResponseProperties)
    {
        responseProperties = aResponseProperties;
    }

    private void createOrgentityMessage() throws ECException
    {
        final String METHODNAME = "createOrgentityMessage";
        ECTrace.entry(ECTraceIdentifiers.COMPONENT_EXTERN, CLASSNAME, METHODNAME);

        String msgType = "OrganizationCreateXMLMessage";
        Integer iMsgType = null;

        try
        {

            MsgTypesAccessBean abMsgTypes = new MsgTypesAccessBean();
            Enumeration emList = abMsgTypes.findByMsgTName(msgType);
            // "OrganizationCreateXMLMessage" MessageType should have been created and configured
            // with MQ Transport in the WebSphere Commerce Administration Console
            if (emList.hasMoreElements())
            {
                iMsgType = ((MsgTypesAccessBean)emList.nextElement()).getMsgtype_id();
                ECTrace.trace(ECTraceIdentifiers.COMPONENT_EXTERN,CLASSNAME, METHODNAME,"MessageTypeId for " + msgType + " = " + iMsgType);
            }
            else
            {
                ECTrace.trace(ECTraceIdentifiers.COMPONENT_EXTERN,CLASSNAME, METHODNAME,"NO MessageTypeId for messageName: " + msgType);
            }

        }
        catch (javax.ejb.CreateException e)
        {
            throw new ECSystemException(
                                       ECMessage._ERR_CREATE_EXCEPTION,
                                       CLASSNAME,
                                       METHODNAME,
                                       ECMessageHelper.generateMsgParms(e.toString()),
                                       e,
                                       true);
        }
        catch (javax.ejb.FinderException e)
        {
            throw new ECSystemException(
                                       ECMessage._ERR_FINDER_EXCEPTION,
                                       CLASSNAME,
                                       METHODNAME,
                                       ECMessageHelper.generateMsgParms(e.toString()),
                                       e,
                                       true);
        }
        catch (javax.naming.NamingException e)
        {
            throw new ECSystemException(
                                       ECMessage._ERR_NAMING_EXCEPTION,
                                       CLASSNAME,
                                       METHODNAME,
                                       ECMessageHelper.generateMsgParms(e.toString()),
                                       e,
                                       true);
        }
        catch (java.rmi.RemoteException e)
        {
            throw new ECSystemException(
                                       ECMessage._ERR_REMOTE_EXCEPTION,
                                       CLASSNAME,
                                       METHODNAME,
                                       ECMessageHelper.generateMsgParms(e.toString()),
                                       e,
                                       true);
        }
        /* Fetch the newly created orgEntityID and parentMemberID */

        String parentMemberId = requestProperties.getString("parentMemberId");
        String orgEntityId = responseProperties.getString("orgEntityId");

        // Set the two ID's retreived into request propeties, which will be made available to the JSP
        requestProperties.put(ECUserConstants.EC_ORG_MEMBERID,parentMemberId);
        requestProperties.put(ECUserConstants.EC_ORG_ORGENTITYID,orgEntityId);

        try
        {

            Messaging ms = new Messaging(iMsgType, getCommandContext().getStoreId());
            ms.compose(null, getCommandContext(), requestProperties);

            int returncode = ms.sendImmediate();
            // do nothing with return code, just put in the trace
            ECTrace.trace(ECTraceIdentifiers.COMPONENT_EXTERN,CLASSNAME, METHODNAME,"return code value "+  returncode+ " \r\n");
        }
        catch (Exception e)
        {

            ECTrace.trace(ECTraceIdentifiers.COMPONENT_EXTERN,CLASSNAME, METHODNAME,"Caught Exception "+ e + " \r\n");
            throw new ECSystemException(
                                       ECMessage._ERR_COMMAND_EXCEPTION,
                                       CLASSNAME,
                                       METHODNAME,
                                       ECMessageHelper.generateMsgParms(e.toString()),
                                       e,
                                       true);
        }


        ECTrace.exit(ECTraceIdentifiers.COMPONENT_EXTERN,CLASSNAME,METHODNAME);
    }

}

