<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!--
 ***********************************************************************
 * Licensed Materials - Property of IBM
 *
 * 5724-A18
 *
 * (c) Copyright International Business Machines Corporation. 2003,2004
 *     All rights reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 ***********************************************************************


 ***********************************************************************
 * The sample contained herein is provided to you "AS IS".
 *
 * It is furnished by IBM as a simple example and has not been  
 * thoroughly tested under all conditions.  IBM, therefore, cannot
 * guarantee its reliability, serviceability or functionality.  
 *
 * This sample may include the names of individuals, companies, brands 
 * and products in order to illustrate concepts as completely as 
 * possible.  All of these names are fictitious and any similarity
 * to the names and addresses used by actual persons or business
 * enterprises is entirely coincidental.
 ***********************************************************************
-->

<!-- XSL Rule file to transform extracted Data from Siebel to WCS -->

<!-- Variable Name Definations Section Starts -->
  <xsl:param name="ImportLocation" select="'import.dtd'"/>   
  <xsl:variable name="RootElement">import</xsl:variable> 
  <xsl:variable name="VersionElement">V5.5</xsl:variable> 
  <xsl:variable name="RootPrefix">@</xsl:variable>
  <xsl:variable name="RecordSeperator">&#13;</xsl:variable>   
  
  <xsl:variable name="attrtypeid">STRING</xsl:variable>
  <xsl:variable name="CatentryRelationType">PRODUCT_ITEM</xsl:variable>
  <xsl:variable name="CatentryItemType">ItemBean</xsl:variable>
  <xsl:variable name="CatentryProductType">ProductBean</xsl:variable>
  <xsl:variable name="BaseItemType">ITEM</xsl:variable>
  <xsl:variable name="HundredValue">100</xsl:variable>
  <xsl:variable name="FalseFlag">N</xsl:variable>
  <xsl:variable name="TrueFlag">Y</xsl:variable>
  <xsl:variable name="ZeroValue">0</xsl:variable>
  <xsl:variable name="OneValue">1</xsl:variable>

  
  <xsl:variable name="Englishid">en_US</xsl:variable>
  <xsl:variable name="Germanid">de_DE</xsl:variable>
  <xsl:variable name="Chineseid">zh_CN</xsl:variable>
  <xsl:variable name="Thaiid">zh_TW</xsl:variable>
  <xsl:variable name="Koreanid">ko_KR</xsl:variable>
  <xsl:variable name="Frenchid">fr_FR</xsl:variable>
  <xsl:variable name="Italianid">it_IT</xsl:variable>
  <xsl:variable name="Japaneseid">ja_JP</xsl:variable>
  <xsl:variable name="Portugueseid">pt_BR</xsl:variable>
  <xsl:variable name="Spanishid">es_ES</xsl:variable>

  <xsl:variable name="DefaultUOM">C62</xsl:variable>

  <!-- Varibale to construct default Product description and Name -->
  <xsl:variable name="DefaultProductDesc">Product - </xsl:variable>


  <xsl:param name="DefaultCatgroupIdentifier" select="'SBL Products'"/>
  <xsl:param name="DefaultSubCatgroupIdentifier" select="'SBL Category 1'"/>
  <xsl:param name="DefaultSubCatgroupDescription" select="'SBL Drill bits'"/>
  <xsl:param name="DefaultProductPartNumber" select="'SBL10001'"/>
  <xsl:param name="DefaultProductMFPartNumber" select="'SBL-Tools-10001'"/>
  <xsl:param name="DefaultProductMFName" select="'SBL Tools'"/>


  <xsl:param name="StoreIdentifier" select="10001"/>
  <xsl:param name="MemberIdentifier" select="-2000"/>   
  <xsl:param name="TradingPositionName" select="'ToolTech'"/>  
  <xsl:param name="CatalogName" select="'ToolTech1'"/>   
  <xsl:param name="FullFillmentCenterName" select="'ToolTech'"/>


  <!-- Variable Name Definitions Section Ends -->

  <!-- Transformation Rules Section Starts -->
<xsl:template match="/"> 
<xsl:text disable-output-escaping = "yes">&lt;!DOCTYPE import SYSTEM "</xsl:text> 
<xsl:value-of select = "$ImportLocation"/> 
<xsl:text disable-output-escaping = "yes">"&gt;&#13;</xsl:text> 
<xsl:element name="{$RootElement}">


	<xsl:for-each select=".//InternalProduct">
		<xsl:call-template name="Create"/>
	</xsl:for-each>

</xsl:element>	

</xsl:template>


<!-- Transformation Rules Section Ends -->


<!-- Transformation Rules for relating item to CATENTRY starts -->


<xsl:template name="Create">

<!-- CATENTRY -->
<!-- ======== -->

	<xsl:element name="catentry">      
		<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  	<xsl:value-of select="$MemberIdentifier"/>
                  	<xsl:value-of select="$RootPrefix"/>
     	            	<xsl:value-of select="Part"/>
              	</xsl:attribute>
		<xsl:attribute name="member_id">
	        	<xsl:value-of select="$MemberIdentifier"/>
              	</xsl:attribute>
		<xsl:attribute name="catenttype_id">
	        	<xsl:value-of select="$CatentryItemType"/>
              	</xsl:attribute>
		<xsl:attribute name="markfordelete">
	                <xsl:value-of select="$ZeroValue"/>
              	</xsl:attribute>
		<xsl:attribute name="buyable">
	                <xsl:value-of select="$OneValue"/>
              	</xsl:attribute>
<!--
		<xsl:attribute name="itemspc_id">
			<xsl:value-of select="$RootPrefix"/>
                 	<xsl:value-of select="$MemberIdentifier"/>
	            	<xsl:value-of select="$RootPrefix"/>
     	            	<xsl:value-of select="Part"/>
              	</xsl:attribute>
-->
		<xsl:attribute name="partnumber">
			<xsl:value-of select="normalize-space(Part)"/>
		</xsl:attribute>
		
		<xsl:attribute name="mfpartnumber">
			<xsl:choose>
				<xsl:when test="normalize-space(VendorPartNumber)=''">
					<xsl:value-of select="normalize-space(Part)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(VendorPartNumber)"/>
				</xsl:otherwise>
		 	</xsl:choose>
		</xsl:attribute>
		<xsl:attribute name="mfname">
			<xsl:choose>
				<xsl:when test="normalize-space(VendorId)=''">
					<xsl:value-of select="$DefaultProductMFName"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(VendorId)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	</xsl:element> 	

<!-- LISTPRICE -->
<!-- ========= -->

	<xsl:element name="listprice">
		<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  	<xsl:value-of select="$MemberIdentifier"/>
           		<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="Part"/>
        	</xsl:attribute>
		<xsl:attribute name="listprice">
			<xsl:value-of select="normalize-space(ListPrice)"/>
        	</xsl:attribute>
		<xsl:attribute name="currency">
			<xsl:value-of select="normalize-space(CostListItemCurrencyCode)"/>
		</xsl:attribute>		
	</xsl:element>

<!-- CATENDDESC -->
<!-- ========== -->

	<xsl:element name="catentdesc">
		<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  	<xsl:value-of select="$MemberIdentifier"/>
	            	<xsl:value-of select="$RootPrefix"/>
			<xsl:choose>
				<xsl:when test="normalize-space(Part)=''">
					<xsl:value-of select="$DefaultProductPartNumber"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(Part)"/>
				</xsl:otherwise>
			</xsl:choose>
               	</xsl:attribute>
		<xsl:attribute name="published">
	                  <xsl:value-of select="$OneValue"/>
              	</xsl:attribute>
		<xsl:attribute name="available">
	                  <xsl:value-of select="$OneValue"/>
              	</xsl:attribute>

		<xsl:attribute name="language_id">
			<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="$Englishid"/>
<!--
			<xsl:choose>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='English'">
					<xsl:value-of select="$Englishid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='German'">
					<xsl:value-of select="$Germanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Chinese'">
					<xsl:value-of select="$Chineseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Thai'">
					<xsl:value-of select="$Thaiid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Korean'">
					<xsl:value-of select="$Koreanid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='French'">
					<xsl:value-of select="$Frenchid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Italian'">
					<xsl:value-of select="$Italianid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Japanese'">
					<xsl:value-of select="$Japaneseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Portuguese'">
					<xsl:value-of select="$Portugueseid"/>
				</xsl:when>
				<xsl:when test="normalize-space(@parentdesclanguage_id)='Spanish'">
					<xsl:value-of select="$Spanishid"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Englishid"/>
				</xsl:otherwise>
			</xsl:choose>
-->
		</xsl:attribute>

		<!-- When no name or shortdescription is present for parent product then we construct the description
			as Product - <material group partnumber> -->

		<xsl:attribute name="shortdescription">
 			 <xsl:choose>
				<xsl:when test="normalize-space(Description)=''">
					<xsl:value-of select="$DefaultProductDesc"/>
					<xsl:value-of select="normalize-space(part)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(Description)"/>
				</xsl:otherwise>
			 </xsl:choose>
		</xsl:attribute>
			
		<xsl:attribute name="name">
			<xsl:choose>
				<xsl:when test="normalize-space(Name2)=''">
					<xsl:value-of select="$DefaultProductDesc"/>
					<xsl:value-of select="normalize-space(Part)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(Name2)"/>
				</xsl:otherwise>
			 </xsl:choose>
		</xsl:attribute>
	</xsl:element>                                                                                   

<!-- END OF CATENDDESC -->
<!-- ================= -->

<!-- STORECENT -->
<!-- ========= -->

	<xsl:element name="storecent">      
        	<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  	<xsl:value-of select="$MemberIdentifier"/>
	            	<xsl:value-of select="$RootPrefix"/>
     	            	<xsl:value-of select="Part"/>
              	</xsl:attribute>
		<xsl:attribute name="storeent_id">
                	<xsl:value-of select="$StoreIdentifier"/>
              	</xsl:attribute>
	</xsl:element> 

<!-- END OF STORECENT -->
<!-- ================ -->


<!-- CATENTSHIP -->
<!-- ========== -->

	<xsl:element name="catentship">
		<xsl:attribute name="catentry_id">
			<xsl:value-of select="$RootPrefix"/>
                  	<xsl:value-of select="$MemberIdentifier"/>
           		<xsl:value-of select="$RootPrefix"/>
			<xsl:value-of select="Part"/>
     		</xsl:attribute>

<!--
		<xsl:attribute name="nominalquantity">
			<xsl:choose>
				<xsl:when test="normalize-space(@nominalquantity)='0.000'">
					<xsl:value-of select="$OneValue"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(@nominalquantity)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
-->
		<xsl:attribute name="quantitymeasure">
			<xsl:choose>
				<xsl:when test="normalize-space(UnitofMeasure)='Each'">
					<xsl:value-of select="$DefaultUOM"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="normalize-space(UnitofMeasure)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	
	</xsl:element> 

<!-- END OF CATENTSHIP -->
<!-- ================= -->





</xsl:template>


</xsl:stylesheet>
